@@ -417,14 +417,6 @@ case 'init'
         if FMRI.dime_z < 15,
             set(h1,'enable','off');
         end
-	pos = [685 25 50 25];
-	h1 = uicontrol(...
-            'style','pushbutton',...
-            'string','Montage',...
-            'position', pos,...
-            'backgroundcolor',RGB_button,...
-            'foregroundcolor',RGB_text,...
-            'callback','map_on_fmri2(''montage'');');
         pos = [685 110 50 20];
         h1 = uicontrol(...
             'style','text',...
@@ -485,76 +477,7 @@ case 'init'
         figure(f_main);
         map_on_fmri2('fresh');
     end
-
- case 'montage'
-  f_main = findobj('name',...
-		   ['Display Component ROA on Functional Variance' ...
-		    ' Images']);
-  set(f_main,'pointer','watch');
-  avg_image = sqrt(std(FMRI.data));
-  base_image = zeros(FMRI.dime_x*FMRI.dime_y*FMRI.dime_z,1);
-  for i=1:length(FMRI.idx),
-    base_image(FMRI.idx(i)) = avg_image(i);
-  end
-  base_image = fmrlab_scale(base_image,1,64);
-  
-  % find the displaying parameters
-  a = findobj(f_main,'tag','ed_thre');
-  uthre = str2num(get(a,'string'));
-  lthre = -1 * uthre;
-  a = findobj(f_main,'tag','ed_lim');
-  ulim = str2num(get(a,'string'));
-  llim = -1 * ulim;
-  
-  % get current component
-  a = findobj(f_main,'tag','ed_component');
-  comp = str2num(get(a,'string'));
-  % calculating component map
-  W = FMRI.icaweight * FMRI.icasphere;
-  invW = pinv(W);
-  u = W * FMRI.data;
-  temp_data = u(comp, :);
-  mean_temp_data = mean(temp_data);
-  std_temp_data = std(temp_data);
-  temp_data = (temp_data-mean_temp_data)/std_temp_data; %convert to z score
-  uidx = find(temp_data >= ulim);
-  temp_data(uidx) = ulim;
-  uidx = find(temp_data >= uthre);
-  umap = zeros(length(temp_data),1);
-  umap(uidx) = temp_data(uidx);
-  umap(uidx) = fmrlab_scale(umap(uidx),101,128,uthre,ulim);
-  map = zeros(FMRI.dime_x*FMRI.dime_y*FMRI.dime_z,1);
-  for i=1:length(FMRI.idx),
-    map(FMRI.idx(i)) = umap(i);
-  end
-  img = max(base_image,map);
-  
-  lidx = find(temp_data <= llim);
-  temp_data(lidx) = llim;
-  lidx = find(temp_data <= lthre);
-  lmap = zeros(length(temp_data),1);
-  lmap(lidx) = temp_data(lidx);
-  lmap(lidx) = fmrlab_scale(lmap(lidx),65,92,llim,lthre);
-  map = zeros(FMRI.dime_x*FMRI.dime_y*FMRI.dime_z,1);
-  for i=1:length(FMRI.idx),
-    map(FMRI.idx(i)) = lmap(i);
-  end
-  img = max(img,map);
-  img = reshape(img,FMRI.dime_x,FMRI.dime_y,FMRI.dime_z);
-
-  % display component maps
-  img2 = zeros(FMRI.dime_y,FMRI.dime_x,1,FMRI.dime_z);
-  for i=1:FMRI.dime_z,
-    temp = img(:,:,i);
-    img2(:,:,1,i) = temp';
-  end
-  figure
-  montage(img2,fmrlab_color(2));
-  ti = title(['Component ' num2str(comp)]);
-  set(ti,'fontsize',16);
-  set(gcf,'color',RGB_mainwin);
-  set(f_main,'pointer','arrow');
-  
+     
 case 'tc_clicked'
 	a = findobj('tag','list_tc');
 	b = get(a,'value');
