@@ -423,14 +423,6 @@ case 'init'
         if FMRI.dime_z < 15,
             set(h1,'enable','off');
         end
-	pos = [685 25 50 25];
-	h1 = uicontrol(...
-            'style','pushbutton',...
-            'string','Montage',...
-            'position', pos,...
-            'backgroundcolor',RGB_button,...
-            'foregroundcolor',RGB_text,...
-            'callback','map_on_struc2(''montage'');');
         pos = [685 110 50 20];
         h1 = uicontrol(...
             'style','text',...
@@ -492,100 +484,7 @@ case 'init'
         map_on_struc2('fresh');
     end
  
- case 'montage'
-  f_main = findobj('name',...
-		   ['Display Component ROA on Structural' ...
-		    ' Images']);
-  set(f_main,'pointer','watch');
-  
-  fname = [FMRI.struc_path FMRI.struc_name];
-  fp = fopen(fname,'rb','ieee-be');
-  avg_image = fread(fp,'uint16');
-  fclose(fp);
-  struc_image_width = FMRI.struc_image_width;
-  struc_image_height = FMRI.struc_image_height;
-  struc_slice_no = FMRI.struc_image_depth;
-  base_image = zeros(1,struc_image_width*struc_image_height*struc_slice_no);
-  base_image = fmrlab_scale(avg_image,1,64);
-  BASEIMG = base_image;
-  base_image = reshape(base_image,struc_image_width, ...
-		       struc_image_height,struc_slice_no);
-
-  % find the displaying parameters
-  a = findobj(f_main,'tag','ed_thre');
-  uthre = str2num(get(a,'string'));
-  lthre = -1 * uthre;
-  a = findobj(f_main,'tag','ed_lim');
-  ulim = str2num(get(a,'string'));
-  llim = -1 * ulim;
-  
-  % get current component
-  a = findobj(f_main,'tag','ed_component');
-  comp = str2num(get(a,'string'));
-  % calculating component map
-  W = FMRI.icaweight * FMRI.icasphere;
-  invW = pinv(W);
-  u = W * FMRI.data;
-  temp_data = u(comp, :);
-  mean_temp_data = mean(temp_data);
-  std_temp_data = std(temp_data);
-  temp_data = (temp_data-mean_temp_data)/std_temp_data; %convert to z score
-  uidx = find(temp_data >= uthre);
-  temp_data1 = zeros(FMRI.dime_x*FMRI.dime_y*...
-		     FMRI.dime_z,1);
-  for i=1:length(FMRI.idx),
-    temp_data1(FMRI.idx(i)) = temp_data(i);
-  end
-  temp_data1 = reshape(temp_data1,FMRI.dime_x, FMRI.dime_y, ...
-		       FMRI.dime_z);
-  if struc_image_width ~= FMRI.dime_x,
-    xs = linspace(1, struc_image_width, FMRI.dime_x);
-    ys = linspace(1, struc_image_height, FMRI.dime_y);    
-    [xi, yi] = meshgrid(1:struc_image_width, 1:struc_image_height); 
-    smap = [];
-    for i=1:FMRI.dime_z,
-      temp_data2 = interp2(xs, ys, temp_data1(:,:,i), xi, yi);
-      temp_data2 = reshape(temp_data2, struc_image_width*struc_image_height, 1);
-      smap = [smap temp_data2];
-    end
-  else
-    smap = temp_data1;
-  end
-  smap = reshape(smap,struc_image_width*struc_image_height*...
-		 FMRI.dime_z,1);
-  pos_smap = smap;
-  ii = find(pos_smap > ulim);
-  pos_smap(ii) = ulim;
-  ii = find(pos_smap < uthre);
-  pos_smap(ii) = 0.0;
-  ii = find(pos_smap >= uthre);
-  pos_smap(ii) = fmrlab_scale(pos_smap(ii),99,128);
-  BASEIMG = reshape(BASEIMG,struc_image_width*struc_image_height*FMRI.dime_z,1);
-  img = max(BASEIMG,pos_smap);
-  
-  neg_smap = smap;
-  ii = find(neg_smap < llim);
-  neg_smap(ii) = llim;
-  ii = find(neg_smap > lthre);
-  neg_smap(ii) = 0.0;
-  ii = find(neg_smap <= lthre);
-  neg_smap(ii) = fmrlab_scale(neg_smap(ii),65,94);
-  img = max(img,neg_smap);
-  img = reshape(img,struc_image_width,struc_image_height,FMRI.dime_z);
-
-  % display component maps
-  img2 = zeros(struc_image_height,struc_image_width,1,FMRI.dime_z);
-  for i=1:FMRI.dime_z,
-    temp = img(:,:,i);
-    img2(:,:,1,i) = temp';
-  end
-  figure
-  montage(img2,fmrlab_color(2));
-  ti = title(['Component ' num2str(comp)]);
-  set(ti,'fontsize',16);
-  set(gcf,'color',RGB_mainwin);
-  set(f_main,'pointer','arrow');
-
+     
 case 'tc_clicked'
 	a = findobj('tag','list_tc');
 	b = get(a,'value');
